import requests
import logging

log = logging.getLogger('py_piwik/helpers')

api_url = ''
api_token = ''


def _url(path: str) -> str:
    return api_url + path


def _finalize_args(args: dict, token: str, method: str) -> dict:
    args['format'] = 'JSON'
    args['module'] = 'API'
    args['token_auth'] = token
    args['method'] = method

    return args


def _process_request(url: str, args: dict):
    try:
        results = requests.get(url, params=args)
        log.debug(results.url)
    except ConnectionError as err:
        log.error(err)
        raise err
    else:
        if not results.ok:
            log.debug(results)
            raise requests.HTTPError
        return results.json()



from py_piwik.sites_manager import *
import responses
from os import environ

testing_url = 'https://piwik.testing/index.php'
testing_token = '1234567890'

client = SitesManager(testing_url, testing_token)

@responses.activate
def test_get_site_urls_from_id():
    res_json = [
        {
            "idsite": "12",
            "name": "CBD",
            "main_url": "https://tryoilhemp.com",
            "ts_created": "2017-09-13 00:00:00",
            "ecommerce": "0",
            "sitesearch": "1",
            "sitesearch_keyword_parameters": "",
            "sitesearch_category_parameters": "",
            "timezone": "America/Denver",
            "currency": "USD",
            "exclude_unknown_urls": "0",
            "excluded_ips": "",
            "excluded_parameters": "",
            "excluded_user_agents": "",
            "group": "",
            "type": "website",
            "keep_url_fragment": "0"
        }
    ]

    responses.add(responses.Response(
        method='GET',
        url=testing_url+'?idSite=12&format=JSON&module=API&token_auth='+ testing_token + '&method=SitesManager.getSiteUrlsFromId',
        match_querystring=True,
        json=res_json
    ))

    args = {
        'idSite': str(12)
    }

    res = client.get_site_urls_from_id(args)

    assert res == [
        {
            "idsite": "12",
            "name": "CBD",
            "main_url": "https://tryoilhemp.com",
            "ts_created": "2017-09-13 00:00:00",
            "ecommerce": "0",
            "sitesearch": "1",
            "sitesearch_keyword_parameters": "",
            "sitesearch_category_parameters": "",
            "timezone": "America/Denver",
            "currency": "USD",
            "exclude_unknown_urls": "0",
            "excluded_ips": "",
            "excluded_parameters": "",
            "excluded_user_agents": "",
            "group": "",
            "type": "website",
            "keep_url_fragment": "0"
        }
    ]



from py_piwik.helpers import _finalize_args, _process_request
import logging

log = logging.getLogger('py_piwik/goals')


class Goals(object):

    def __init__(self, url: str, token: str):
        """
        Provides Access to the API Module Goals
        """
        self.url = url
        self.token = token

    def get_goal(self, args):
        """
        :param args: api arguments
        :type args: dict

        :return:
        """

        if 'idSite' not in args:
            raise ValueError('Missing required argument args[\'idSite\']')

        if 'idGoal' not in args:
            raise ValueError('Missing required argument args[\'idGoal\']')

        fargs = _finalize_args(args, self.token, 'Goals.getGoal')

        results = _process_request(self.url, fargs)

        return results

    def get_goals(self, args: dict) -> list:
        """
        Return list of goals for siteID

        :param args: api arguments
        :type args: dict

        :return: list of goals
        """

        if 'idSite' not in args:
            raise ValueError('Missing required argument args[\'idSite\']')

        fargs = _finalize_args(args, self.token, 'Goals.getGoals')

        results = _process_request(self.url, fargs)

        return results

    def add_goal(self, args: dict):
        """
        :param args: api arguments
        :type args: dict

        :return:
        """

        if 'idSite' not in args:
            raise ValueError('Missing required argument args[\'idSite\']')

        if 'name' not in args:
            raise ValueError('Missing required argument args[\'name\']')

        if 'matchAttribute' not in args:
            raise ValueError('Missing required argument args[\'matchAttribute\']')

        if 'pattern' not in args:
            raise ValueError('Missing required argument args[\'pattern\']')

        if 'patternType' not in args:
            raise ValueError('Missing required argument args[\'patternType\']')

        fargs = _finalize_args(args, self.token, 'Goals.addGoal')

        results = _process_request(self.url, fargs)

        return results

    def update_goal(self, args: dict):
        """
        :param args: api arguments
        :type args: dict

        :return:
        """

        if 'idSite' not in args:
            raise ValueError('Missing required argument args[\'idSite\']')

        if 'idGoal' not in args:
            raise ValueError('Missing required argument args[\'idGoal\']')

        if 'name' not in args:
            raise ValueError('Missing required argument args[\'name\']')

        if 'matchAttribute' not in args:
            raise ValueError('Missing required argument args[\'matchAttribute\']')

        if 'pattern' not in args:
            raise ValueError('Missing required argument args[\'pattern\']')

        if 'patternType' not in args:
            raise ValueError('Missing required argument args[\'patternType\']')

        fargs = _finalize_args(args, self.token, 'Goals.updateGoal')

        results = _process_request(self.url, fargs)

        return results

    def delete_goal(self, args):
        """
        :param args: api arguments
        :type args: dict

        :return:
        """

        if 'idSite' not in args:
            raise ValueError('Missing required argument args[\'idSite\']')

        if 'idGoal' not in args:
            raise ValueError('Missing required argument args[\'idGoal\']')

        fargs = _finalize_args(args, self.token, 'Goals.deleteGoal')

        results = _process_request(self.url, fargs)

        return results

    def get_item_sku(self, args):
        """
        :param args: api arguments
        :type args: dict

        :return:
        """

        if 'idSite' not in args:
            raise ValueError('Missing required argument args[\'idSite\']')
        if 'period' not in args:
            raise ValueError('Missing required argument args[\'period\']')
        if 'date' not in args:
            raise ValueError('Missing required argument args[\'date\']')

        fargs = _finalize_args(args, self.token, 'Goals.getItemsSku')

        results = _process_request(self.url, fargs)

        return results

    def get_item_name(self, args):
        """
        :param args: api arguments
        :type args: dict

        :return:
        """

        if 'idSite' not in args:
            raise ValueError('Missing required argument args[\'idSite\']')
        if 'period' not in args:
            raise ValueError('Missing required argument args[\'period\']')
        if 'date' not in args:
            raise ValueError('Missing required argument args[\'date\']')

        fargs = _finalize_args(args, self.token, 'Goals.getItemsName')

        results = _process_request(self.url, fargs)

        return results

    def get_item_category(self, args):
        """
        :param args: api arguments
        :type args: dict

        :return:
        """

        if 'idSite' not in args:
            raise ValueError('Missing required argument args[\'idSite\']')
        if 'period' not in args:
            raise ValueError('Missing required argument args[\'period\']')
        if 'date' not in args:
            raise ValueError('Missing required argument args[\'date\']')

        fargs = _finalize_args(args, self.token, 'Goals.getItemsCategory')

        results = _process_request(self.url, fargs)

        return results

    def get(self, args: dict) -> dict:
        """
        Return data related to a goal

        :param args: api arguments
        :type args: dict

        :return: goal data
        """

        if 'idSite' not in args:
            raise ValueError('Missing required argument args[\'idSite\']')
        if 'period' not in args:
            raise ValueError('Missing required argument args[\'period\']')
        if 'date' not in args:
            raise ValueError('Missing required argument args[\'date\']')

        fargs = _finalize_args(args, self.token, 'Goals.get')

        results = _process_request(self.url, fargs)

        return results

    def get_days_to_conversion(self, args):
        """
        :param args: api arguments
        :type args: dict

        :return: goal data
        """

        if 'idSite' not in args:
            raise ValueError('Missing required argument args[\'idSite\']')
        if 'period' not in args:
            raise ValueError('Missing required argument args[\'period\']')
        if 'date' not in args:
            raise ValueError('Missing required argument args[\'date\']')

        fargs = _finalize_args(args, self.token, 'Goals.getDaysToConversion')

        results = _process_request(self.url, fargs)

        return results

    def get_visits_until_conversion(self, args):
        """
                :param args: api arguments
                :type args: dict

                :return: goal data
                """

        if 'idSite' not in args:
            raise ValueError('Missing required argument args[\'idSite\']')
        if 'period' not in args:
            raise ValueError('Missing required argument args[\'period\']')
        if 'date' not in args:
            raise ValueError('Missing required argument args[\'date\']')

        fargs = _finalize_args(args, self.token, 'Goals.getVisitsUntilConversion')

        results = _process_request(self.url, fargs)

        return results



from setuptools import setup, find_packages
import requests

version = '0.1.4'


def readme():
    r = requests.post(url='http://c.docverter.com/convert',
                      data={'to': 'rst', 'from': 'markdown'},
                      files={'input_files[]': open('README.md', 'rb')})
    if r.ok:
        return r.content.encode()
    else:
        return 'error converting readme'


setup(name='py-piwik',
      version=version,
      description='Piwik API Client',
      # long_description=readme(),
      classifiers=[
          'Intended Audience :: Developers',
          'Development Status :: 4 - Beta',
          'License :: OSI Approved :: MIT License',
          'Natural Language :: English',
          'Programming Language :: Python :: 3 :: Only'
      ],
      keywords='piwik api client',
      url='https://github.com/adminhead-tech/pypiwik',
      author='AdminHead',
      author_email='code@adminhead.tech',
      license='MIT',
      packages=find_packages(exclude=['contrib', 'docs', 'tests']),
      install_requires=[
          'requests'
      ],
      extras_require={
          'dev': ['pytest', 'responses']
      },
      python_requires='>=3',
      include_package_data=True,
      zip_safe=False)
